diff -ruN nagiosplug-save/plugins-scripts/check_breeze.pl nagiosplug/plugins-scripts/check_breeze.pl
--- nagiosplug-save/plugins-scripts/check_breeze.pl	2004-02-21 03:42:43.000000000 +0000
+++ nagiosplug/plugins-scripts/check_breeze.pl	2004-03-27 21:43:26.000000000 +0000
@@ -1,87 +1,80 @@
 #!/usr/bin/perl -wT
 
 
+require 5.004;
+use POSIX;
 use strict;
-use Getopt::Long;
-use vars qw($opt_V $opt_h $opt_w $opt_c $opt_H $opt_C $PROGNAME);
 use lib utils.pm ;
-use utils qw(%ERRORS &print_revision &support &usage);
+use Plugin;
+use Plugin::Parameter qw($helpparameterlist $versionparameterlist $hostnameparameter
+			 $communityparameter $portparameter $warningparameter
+			 $criticalparameter $timeoutparameter $verboseparameter);
 
-$PROGNAME = "check_breeze";
+use Net::SNMP;
 
-sub print_help ();
-sub print_usage ();
+use vars qw($opt_h $opt_w $opt_c $opt_H $opt_C $opt_p $opt_t $opt_v $xml $PROGNAME);
+use utils qw(%ERRORS &usage);
 
 $ENV{'PATH'}='';
 $ENV{'BASH_ENV'}=''; 
 $ENV{'ENV'}='';
 
-Getopt::Long::Configure('bundling');
-GetOptions
-	("V"   => \$opt_V, "version"    => \$opt_V,
-	 "h"   => \$opt_h, "help"       => \$opt_h,
-	 "w=s" => \$opt_w, "warning=s"  => \$opt_w,
-	 "c=s" => \$opt_c, "critical=s" => \$opt_c,
-	 "H=s" => \$opt_H, "hostname=s" => \$opt_H,
-	 "C=s" => \$opt_C, "community=s" => \$opt_C);
-
-if ($opt_V) {
-	print_revision($PROGNAME,'$Revision: 1.5 $');
-	exit $ERRORS{'OK'};
+$portparameter->default(161);
+$warningparameter->type("PERCENT");
+$warningparameter->checker(\&Plugin::Parameter::_check_percent);
+$warningparameter->description("Percentage strength below which a WARNING status will result");
+$criticalparameter->type("PERCENT");
+$criticalparameter->checker(\&Plugin::Parameter::_check_percent);
+$criticalparameter->description("Percentage strength below which a CRITICAL status will result");
+
+my @commandparameterlist = ( $hostnameparameter,
+			     $communityparameter,
+			     $portparameter,
+			     $warningparameter,
+			     $criticalparameter,
+			     $timeoutparameter,
+			     $verboseparameter );
+
+my $plugin = new Plugin(-revision => '$Revision: 1.5 $',
+			-copyright => "2000 Jeffrey Blank/Karl DeBisschop, 2004 Howard WIlkinson <howard\@cohtech.com>",
+			-shortcomment => "This plugin reports the signal strength of Breezecom wireless equipment",
+			-parameterlists => [ \@commandparameterlist, $helpparameterlist, $versionparameterlist ] );
+
+
+$plugin->init();
+
+my ($session, $error) = Net::SNMP->session(-hostname   => $opt_H,
+					   -community  => $opt_C,
+					   -timeout    => $opt_t,
+					   -port       => $opt_p,
+					   -version    => "snmpv1",
+					   -translate  => undef);
+if (!defined($session)) {
+  print "$PROGNAME UNKNOWN: $error\n";
+  exit $ERRORS{'UNKNOWN'};
 }
 
-if ($opt_h) {print_help(); exit $ERRORS{'OK'};}
+my $snmpBreezeSigStrength = '1.3.6.1.4.1.710.3.2.3.1.3.0';
 
-($opt_H) || usage("Host name/address not specified\n");
-my $host = $1 if ($opt_H =~ /([-.A-Za-z0-9]+)/);
-($host) || usage("Invalid host: $opt_H\n");
+my $response = $session->get_request(-varbindlist => [ $snmpBreezeSigStrength ]);
 
-($opt_w) || usage("Warning threshold not specified\n");
-my $warning = $1 if ($opt_w =~ /([0-9]{1,2}|100)+/);
-($warning) || usage("Invalid warning threshold: $opt_w\n");
-
-($opt_c) || usage("Critical threshold not specified\n");
-my $critical = $1 if ($opt_c =~ /([0-9]{1,2}|100)/);
-($critical) || usage("Invalid critical threshold: $opt_c\n");
-
-($opt_C) || ($opt_C = "public") ;
-
-my $sig=0;
-$sig = `/usr/bin/snmpget $host $opt_C .1.3.6.1.4.1.710.3.2.3.1.3.0`;
-my @test=split(/ /,$sig);
-$sig=$test[2];
-$sig=int($sig);
-if ($sig>100){$sig=100}
+if (!defined $response) {
+  print "$PROGNAME UNKNOWN: ".$session->error."\n";
+  exit $ERRORS{'UNKNOWN'};
+}
 
-print "Signal Strength at: $sig%\n";
+$session->close;
 
-exit $ERRORS{'CRITICAL'} if ($sig<$critical);
-exit $ERRORS{'WARNING'} if ($sig<$warning);
-exit $ERRORS{'OK'};
+my $SignalStrength = int($response->{$snmpBreezeSigStrength});
 
+if ($SignalStrength>100){$SignalStrength=100}
 
-sub print_usage () {
-	print "Usage: $PROGNAME -H <host> [-C community] -w <warn> -c <crit>\n";
-}
+my $status = (($SignalStrength < $opt_c)
+	      ?'CRITICAL'
+	      :(($SignalStrength < $opt_w)
+		?'WARNING'
+		:'OK'));
 
-sub print_help () {
-	print_revision($PROGNAME,'$Revision: 1.5 $');
-	print "Copyright (c) 2000 Jeffrey Blank/Karl DeBisschop
-
-This plugin reports the signal strength of a Breezecom wireless equipment
-
-";
-	print_usage();
-	print "
--H, --hostname=HOST
-   Name or IP address of host to check
--C, --community=community
-   SNMPv1 community (default public)
--w, --warning=INTEGER
-   Percentage strength below which a WARNING status will result
--c, --critical=INTEGER
-   Percentage strength below which a CRITICAL status will result
+print "$PROGNAME $status: Signal Strength at: $SignalStrength%\n";
 
-";
-	support();
-}
+exit $ERRORS{$status};
